@@ -30,7 +30,7 @@ crisk.pre.bart <- function(
                       
                       delta,
                       ## vector of event indicators
-                      ## 0=censoring, 1=cause of interest, 2=other causes
+                      ## 0=censoring, 1=cause 1, 2=cause 2
     
                       x.train=NULL,
                       ## matrix of covariate regressors for cause 1
@@ -50,8 +50,13 @@ crisk.pre.bart <- function(
     ## can be extended later
     ## most likely via the alternative counting process notation
 
-    if(!all(unique(sort(delta))==0:2)) 
-        stop('delta must be coded as: 0(censored), 1(cause of interest) or 2(other cause)')
+    check <- unique(sort(delta))
+
+    C <- length(check)
+    
+    ## with gap times, there is no censoring per se, only 1s and 2s
+    if(!(C %in% 2:3) || (C==3 && !all(check==0:2)) || (C==2 && !all(check==1:2))) 
+        stop('delta must be coded as: 0(censored), 1(cause 1) or 2(cause 2)')
 
     if(length(x.train)>0 && length(x.train2)>0 && nrow(x.train)!=nrow(x.train2))
         stop('number of rows in x.train and x.train2 must be equal')
@@ -64,7 +69,7 @@ crisk.pre.bart <- function(
     pre$cond <- which(pre$y.train==0)
     
     pre2 <- surv.pre.bart(times=times, 1*(delta==2), x.train=x.train2, x.test=x.test2)
-    
+
     pre$tx.train2 <- pre2$tx.train
     pre$tx.test2 <- pre2$tx.test
     pre$y.train2 <- pre2$y.train
