@@ -29,6 +29,9 @@
 
 #ifndef NoRcpp
 
+#define TRDRAW(a, b) trdraw(a, b)
+#define TEDRAW(a, b) tedraw(a, b)
+
 RcppExport SEXP cpbart(
    SEXP _in,            //number of observations in training data
    SEXP _ip,		//dimension of x
@@ -44,6 +47,7 @@ RcppExport SEXP cpbart(
    SEXP _ibase,
    SEXP _binaryOffset,
    SEXP _itau,
+//   SEXP _iM, // number of shards for Modified LISA MCMC
    SEXP _inkeeptrain,
    SEXP _inkeeptest,
    SEXP _inkeeptestme,
@@ -72,6 +76,7 @@ RcppExport SEXP cpbart(
    double alpha = Rcpp::as<double>(_ibase);
    double binaryOffset = Rcpp::as<double>(_binaryOffset);
    double tau = Rcpp::as<double>(_itau);
+//   double rootM = sqrt(Rcpp::as<double>(_iM));
 
    size_t nkeeptrain = Rcpp::as<int>(_inkeeptrain);
    size_t nkeeptest = Rcpp::as<int>(_inkeeptest);
@@ -84,10 +89,7 @@ RcppExport SEXP cpbart(
 
    //return data structures (using Rcpp)
    Rcpp::NumericVector trmean(n); //train
-   for(size_t i=0;i<n;i++) trmean[i]=0.0;
    Rcpp::NumericVector temean(np);
-   for(size_t i=0;i<np;i++) temean[i]=0.0;
-   Rcpp::NumericVector sdraw(nd+burn);
    Rcpp::NumericMatrix trdraw(nkeeptrain,n);
    Rcpp::NumericMatrix tedraw(nkeeptest,np);
    Rcpp::List list_of_lists(nkeeptreedraws*treesaslists);
@@ -97,12 +99,15 @@ RcppExport SEXP cpbart(
 
 #else
 
+#define TRDRAW(a, b) trdraw[a][b]
+#define TEDRAW(a, b) tedraw[a][b]
+
 void cpbart(
    size_t n,            //number of observations in training data
    size_t p,		//dimension of x
    size_t np,		//number of observations in test data
    double* ix,		//x, train,  pxn (transposed so rows are contiguous in memory)
-   double* iy,		//y, train,  nx1
+   int* iy,		//y, train,  nx1
    double* ixp,		//x, test, pxnp (transposed so rows are contiguous in memory)
    size_t m,		//number of trees
    size_t nc,		//number of cut points
@@ -122,16 +127,12 @@ void cpbart(
    unsigned int n2,
    double* trmean,
    double* temean,
-   double* sdraw,
    double* _trdraw,
    double* _tedraw
 )
 {
   
    //return data structures (using C++)
-   for(size_t i=0; i<n; ++i) trmean[i]=0.0;
-   for(size_t i=0; i<np; ++i) temean[i]=0.0;
-
    std::vector<double*> trdraw(nkeeptrain);
    std::vector<double*> tedraw(nkeeptest);
 
@@ -142,7 +143,10 @@ void cpbart(
    arn gen(n1, n2);
 #endif
    
- double* iz = new double[n];
+   for(size_t i=0; i<n; ++i) trmean[i]=0.0;
+   for(size_t i=0; i<np; ++i) temean[i]=0.0;
+
+   double* iz = new double[n];
 
    std::stringstream treess;  //string stream to write trees to  
    treess.precision(10);
@@ -164,20 +168,20 @@ void cpbart(
    //--------------------------------------------------
    //print args
    printf("*****Data:\n");
-   printf("data:n,p,np: %d, %d, %d\n",n,p,np);
+   printf("data:n,p,np: %zu, %zu, %zu\n",n,p,np);
    printf("y1,yn: %d, %d\n",iy[0],iy[n-1]);
    printf("x1,x[n*p]: %lf, %lf\n",ix[0],ix[n*p-1]);
    if(np) printf("xp1,xp[np*p]: %lf, %lf\n",ixp[0],ixp[np*p-1]);
-   printf("*****Number of Trees: %d\n",m);
-   printf("*****Number of Cut Points: %d\n",nc);
-   printf("*****burn and ndpost: %d, %d\n",burn,nd);
+   printf("*****Number of Trees: %zu\n",m);
+   printf("*****Number of Cut Points: %zu\n",nc);
+   printf("*****burn and ndpost: %zu, %zu\n",burn,nd);
    printf("*****Prior:\nbeta,alpha,tau: %lf,%lf,%lf\n",
                    mybeta,alpha,tau);
    printf("*****binaryOffset: %lf\n",binaryOffset);
-   printf("*****nkeeptrain,nkeeptest,nkeeptestme,nkeeptreedraws: %d,%d,%d,%d\n",
+   printf("*****nkeeptrain,nkeeptest,nkeeptestme,nkeeptreedraws: %zu,%zu,%zu,%zu\n",
                nkeeptrain,nkeeptest,nkeeptestme,nkeeptreedraws);
-   printf("*****printevery: %d\n",printevery);
-   printf("*****skiptr,skipte,skipteme,skiptreedraws: %d,%d,%d,%d\n",skiptr,skipte,skipteme,skiptreedraws);
+   printf("*****printevery: %zu\n",printevery);
+   printf("*****skiptr,skipte,skipteme,skiptreedraws: %zu,%zu,%zu,%zu\n",skiptr,skipte,skipteme,skiptreedraws);
 
    //--------------------------------------------------
    bart bm(m);
@@ -214,9 +218,10 @@ void cpbart(
    xinfo& xi = bm.getxinfo();
 
    for(size_t i=0;i<(nd+burn);i++) {
-      if(i%printevery==0) printf("done %d (out of %d)\n",i,nd+burn);
+      if(i%printevery==0) printf("done %zu (out of %lu)\n",i,nd+burn);
       //draw bart
-      bm.draw(1.,gen);
+      bm.draw(1., gen);
+      //bm.draw(rootM, gen);
  
   for(size_t k=0; k<n; k++) {
     if(iy[k]==0) iz[k]= -rtnorm(-bm.f(k), binaryOffset, 1., gen);
@@ -229,12 +234,7 @@ void cpbart(
          if(nkeeptrain && (((i-burn+1) % skiptr) ==0)) {
             //index = trcnt*n;;
             //for(size_t k=0;k<n;k++) trdraw[index+k]=bm.f(k);
-            for(size_t k=0;k<n;k++) 
-	      #ifndef NoRcpp
-	      trdraw(trcnt,k)=bm.f(k);
-	      #else 
-	      trdraw[trcnt][k]=bm.f(k);
-	      #endif
+            for(size_t k=0;k<n;k++) TRDRAW(trcnt,k)=bm.f(k);
             trcnt+=1;
          }
          keeptest = nkeeptest && (((i-burn+1) % skipte) ==0) && np;
@@ -243,12 +243,7 @@ void cpbart(
          if(keeptest) {
             //index=tecnt*np;
             //for(size_t k=0;k<np;k++) tedraw[index+k]=fhattest[k];
-            for(size_t k=0;k<np;k++) 
-	      #ifndef NoRcpp
-	      tedraw(tecnt,k)=fhattest[k];
-	      #else
-	      tedraw[tecnt][k]=fhattest[k];
-	      #endif
+            for(size_t k=0;k<np;k++) TEDRAW(tecnt,k)=fhattest[k];
             tecnt+=1;
          }
          if(keeptestme) {
@@ -261,12 +256,12 @@ void cpbart(
 	   Rcpp::List lists(m*treesaslists);
 	   #endif
 
-            for(size_t jj=0;jj<m;jj++) {
-	      treess << bm.gettree(jj);
+            for(size_t j=0;j<m;j++) {
+	      treess << bm.gettree(j);
 
 	      #ifndef NoRcpp
-	      varcount.row(treedrawscnt)=varcount.row(treedrawscnt)+bm.gettree(jj).tree2count(p);
-	      if(treesaslists) lists(jj)=bm.gettree(jj).tree2list(xi, 0., 1.);
+	      varcount.row(treedrawscnt)=varcount.row(treedrawscnt)+bm.gettree(j).tree2count(p);
+	      if(treesaslists) lists(j)=bm.gettree(j).tree2list(xi, 0., 1.);
 	      #endif
 	    }
 	    #ifndef NoRcpp
@@ -282,7 +277,7 @@ void cpbart(
    for(size_t k=0;k<n;k++) trmean[k]/=nd;
    for(size_t k=0;k<np;k++) temean[k]/=temecnt;
    printf("check counts\n");
-   printf("trcnt,tecnt,temecnt,treedrawscnt: %d,%d,%d,%d\n",trcnt,tecnt,temecnt,treedrawscnt);
+   printf("trcnt,tecnt,temecnt,treedrawscnt: %zu,%zu,%zu,%zu\n",trcnt,tecnt,temecnt,treedrawscnt);
    //--------------------------------------------------
    //PutRNGstate();
 
