@@ -27,6 +27,9 @@
 
 #ifndef NoRcpp
 
+#define TRDRAW(a, b) trdraw(a, b)
+#define TEDRAW(a, b) tedraw(a, b)
+
 RcppExport SEXP cwbart(
    SEXP _in,            //number of observations in training data
    SEXP _ip,		//dimension of x
@@ -88,9 +91,7 @@ RcppExport SEXP cwbart(
 
    //return data structures (using Rcpp)
    Rcpp::NumericVector trmean(n); //train
-   for(size_t i=0;i<n;i++) trmean[i]=0.0;
    Rcpp::NumericVector temean(np);
-   for(size_t i=0;i<np;i++) temean[i]=0.0;
    Rcpp::NumericVector sdraw(nd+burn);
    Rcpp::NumericMatrix trdraw(nkeeptrain,n);
    Rcpp::NumericMatrix tedraw(nkeeptest,np);
@@ -101,6 +102,9 @@ RcppExport SEXP cwbart(
 
 #else
 
+#define TRDRAW(a, b) trdraw[a][b]
+#define TEDRAW(a, b) tedraw[a][b]
+
 void cwbart(
    size_t n,            //number of observations in training data
    size_t p,		//dimension of x
@@ -136,9 +140,6 @@ void cwbart(
 {
 
    //return data structures (using C++)
-   for(size_t i=0; i<n; ++i) trmean[i]=0.0;
-   for(size_t i=0; i<np; ++i) temean[i]=0.0;
-
    std::vector<double*> trdraw(nkeeptrain);
    std::vector<double*> tedraw(nkeeptest);
 
@@ -150,6 +151,9 @@ void cwbart(
 
 #endif
 
+   for(size_t i=0;i<n;i++) trmean[i]=0.0;
+   for(size_t i=0;i<np;i++) temean[i]=0.0;
+
    printf("*****Into main of wbart\n");
    //-----------------------------------------------------------
 
@@ -235,12 +239,7 @@ void cwbart(
          if(nkeeptrain && (((i-burn+1) % skiptr) ==0)) {
             //index = trcnt*n;;
             //for(size_t k=0;k<n;k++) trdraw[index+k]=bm.f(k);
-            for(size_t k=0;k<n;k++) //trdraw(trcnt,k)=bm.f(k);
-	      #ifndef NoRcpp
-	      trdraw(trcnt,k)=bm.f(k);
-	      #else 
-	      trdraw[trcnt][k]=bm.f(k);
-	      #endif
+            for(size_t k=0;k<n;k++) TRDRAW(trcnt,k)=bm.f(k);
             trcnt+=1;
          }
          keeptest = nkeeptest && (((i-burn+1) % skipte) ==0) && np;
@@ -249,12 +248,7 @@ void cwbart(
          if(keeptest) {
             //index=tecnt*np;
             //for(size_t k=0;k<np;k++) tedraw[index+k]=fhattest[k];
-            for(size_t k=0;k<np;k++) //tedraw(tecnt,k)=fhattest[k];
-              #ifndef NoRcpp
-	      tedraw(tecnt,k)=fhattest[k];
-	      #else
-	      tedraw[tecnt][k]=fhattest[k];
-	      #endif
+            for(size_t k=0;k<np;k++) TEDRAW(tecnt,k)=fhattest[k];
             tecnt+=1;
          }
          if(keeptestme) {
@@ -267,12 +261,12 @@ void cwbart(
 	   Rcpp::List lists(m*treesaslists);
 	   #endif
 
-            for(size_t jj=0;jj<m;jj++) {
-	      treess << bm.gettree(jj);
+            for(size_t j=0;j<m;j++) {
+	      treess << bm.gettree(j);
 
 	      #ifndef NoRcpp
-	      varcount.row(treedrawscnt)=varcount.row(treedrawscnt)+bm.gettree(jj).tree2count(p);
-	      if(treesaslists) lists(jj)=bm.gettree(jj).tree2list(xi, 0., 1.);
+	      varcount.row(treedrawscnt)=varcount.row(treedrawscnt)+bm.gettree(j).tree2count(p);
+	      if(treesaslists) lists(j)=bm.gettree(j).tree2list(xi, 0., 1.);
 	      #endif
 	    }
             #ifndef NoRcpp
